@@ -11,4 +11,5 @@
  "puppetserver-confdir"=>"/etc/puppetlabs/puppetserver/conf.d",
  "puppetserver-config"=>
   "/etc/puppetlabs/puppetserver/conf.d/puppetserver.conf",
- :puppet_build_version=>"1d45c3bc74639a15ead4d14cd85a021718ad50c4"}
+ :puppet_build_version=>"018fd02451f52130ec12282a24c6b0f011a56834",
+ :ssh=>{:config=>true}}
