@@ -1,7 +1,7 @@
 (ns puppetlabs.services.master.master-service-test
   (:require
-    [clojure.test :refer :all]
-    [puppetlabs.services.master.master-service :refer :all]
+    [clojure.test :refer [deftest is testing use-fixtures]]
+    ; [puppetlabs.services.master.master-service :refer :all]
     [cheshire.core :as json]
     [clojure.set :as setutils]
     [clojure.string :as str]
@@ -210,7 +210,7 @@
              (is (contains? jruby-metrics :borrow-timers))
              (is (= #{:total :puppet-v3-catalog :puppet-v3-node}
                     (set (keys (:borrow-timers jruby-metrics)))))
-             (doseq [[k v] (:borrow-timers jruby-metrics)]
+             (doseq [[_k v] (:borrow-timers jruby-metrics)]
                (is (nil? (schema/check jruby-metrics-core/TimerSummary v))))))
 
          (is (= 1 (get-in status [:puppet-profiler :service_status_version])))
@@ -246,7 +246,7 @@
        ;; which should cause a subsequent catalog request to block on a borrow
        ;; request
        (jruby-service/with-jruby-puppet
-        _
+        jruby-puppet
         jruby-service
         :master-service-metrics-test
         (let [time-before-second-borrow (System/currentTimeMillis)]
@@ -429,29 +429,29 @@
              non-heap-memory-map (get-memory-map "non-heap")
              total-memory-map (get-memory-map "total")]
          (testing "heap memory metrics work"
-           (= #{"puppetlabs.localhost.memory.heap.committed"
-                "puppetlabs.localhost.memory.heap.init"
-                "puppetlabs.localhost.memory.heap.max"
-                "puppetlabs.localhost.memory.heap.used"} (ks/keyset heap-memory-map))
+           (is (= #{"puppetlabs.localhost.memory.heap.committed"
+                    "puppetlabs.localhost.memory.heap.init"
+                    "puppetlabs.localhost.memory.heap.max"
+                    "puppetlabs.localhost.memory.heap.used"} (ks/keyset heap-memory-map)))
            (is (every? #(< 0 %) (vals heap-memory-map))))
 
          (testing "non-heap memory metrics work"
-           (= #{"puppetlabs.localhost.memory.non-heap.committed"
-                "puppetlabs.localhost.memory.non-heap.init"
-                "puppetlabs.localhost.memory.non-heap.max"
-                "puppetlabs.localhost.memory.non-heap.used"}
-              (ks/keyset non-heap-memory-map))
+           (is (= #{"puppetlabs.localhost.memory.non-heap.committed"
+                    "puppetlabs.localhost.memory.non-heap.init"
+                    "puppetlabs.localhost.memory.non-heap.max"
+                    "puppetlabs.localhost.memory.non-heap.used"}
+                  (ks/keyset non-heap-memory-map)))
            ;; Some of the memory metrics don't propagate correctly on OS X, which can result in a
            ;; value of -1. This is here so that these tests will pass when run in developers local
            ;; environments.
            (is (every? #(or (< 0 %) (= -1 %)) (vals non-heap-memory-map))))
 
          (testing "total memory metrics work"
-           (= #{"puppetlabs.localhost.memory.total.committed"
-                "puppetlabs.localhost.memory.total.init"
-                "puppetlabs.localhost.memory.total.max"
-                "puppetlabs.localhost.memory.total.used"}
-              (ks/keyset total-memory-map))
+           (is (= #{"puppetlabs.localhost.memory.total.committed"
+                    "puppetlabs.localhost.memory.total.init"
+                    "puppetlabs.localhost.memory.total.max"
+                    "puppetlabs.localhost.memory.total.used"}
+                  (ks/keyset total-memory-map)))
            (is (every? #(< 0 %) (vals total-memory-map))))
 
          (testing "uptime metric works"
@@ -548,8 +548,8 @@
                    (make-request-with-metric-id "['puppetdb', 'facts', 'find', 'foonode']")
                    (make-request-with-metric-id "['puppetdb', 'facts', 'search']")
                    (make-request-with-metric-id "['puppetdb', 'resource', 'search', 'Package']")
-                   (= (set master-core/puppet-server-http-client-metrics-for-status)
-                      (set (map :metric-id (get-http-client-metrics-status)))))
+                   (is (= (set master-core/puppet-server-http-client-metrics-for-status)
+                          (set (map :metric-id (get-http-client-metrics-status))))))
 
                  (testing "all metrics contain information they are supposed to have"
                    (let [metrics (get-http-client-metrics-status)]
@@ -597,7 +597,7 @@
 (deftest ^:integration add-metric-ids-to-http-client-metrics-list-test
   (let [test-service (tk-services/service
                       [[:MasterService add-metric-ids-to-http-client-metrics-list!]]
-                      (init [this context]
+                      (init [_this context]
                             (add-metric-ids-to-http-client-metrics-list! [["foo" "bar"]
                                                                           ["hello" "cruel" "world"]])
                             context))]
@@ -694,10 +694,21 @@
          (finally
            (jruby-testutils/return-instance jruby-service jruby-instance :http-report-processor-metrics-test)))))))
 
+(deftest ^:integration compiler-name-as-header
+  (testing "POSTs to the v3 catalog endpoint return the certname as a header"
+    (bootstrap-testutils/with-puppetserver-running
+     app
+     {:jruby-puppet {:gem-path gem-path
+                     :max-active-instances 1
+                     :server-code-dir test-resources-code-dir
+                     :server-conf-dir master-service-test-runtime-dir}}
+     (let [resp (http-post "/puppet/v3/catalog/foo?environment=production" "")]
+       (is (= "localhost" (get-in resp [:headers "x-puppet-compiler-name"])))))))
+
 (deftest encoded-spaces-test
   (testing "Encoded spaces should be routed correctly"
     (bootstrap-testutils/with-puppetserver-running
-     _
+     app
      {:jruby-puppet {:gem-path gem-path
                      :max-active-instances 1
                      :server-conf-dir master-service-test-runtime-dir}}
