@@ -13,7 +13,7 @@
             [puppetlabs.trapperkeeper.services.metrics.metrics-service :as metrics]
             [puppetlabs.services.jruby.jruby-puppet-service :as jruby-puppet]
             [puppetlabs.services.puppet-profiler.puppet-profiler-service :as profiler]
-            [puppetlabs.trapperkeeper.services.webserver.jetty9-service :as jetty9-service]
+            [puppetlabs.trapperkeeper.services.webserver.jetty10-service :as jetty10-service]
             [puppetlabs.services.jruby-pool-manager.jruby-pool-manager-service :as jruby-pool-manager]
             [puppetlabs.trapperkeeper.services.scheduler.scheduler-service :as scheduler-service]
             [puppetlabs.trapperkeeper.services.status.status-service :as status-service]
@@ -46,7 +46,7 @@
    metrics/metrics-service
    scheduler-service/scheduler-service
    status-service/status-service
-   jetty9-service/jetty9-service
+   jetty10-service/jetty10-service
    webrouting-service/webrouting-service])
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -316,7 +316,7 @@ create-mock-pool-instance :- JRubyInstance
    (partial create-mock-jruby-puppet
             (fn [_]
               (JRubyPuppetResponse.
-               (Integer. status-code)
+               (int status-code)
                response-body
                response-content-type
                puppet-version)))))
@@ -361,7 +361,7 @@ create-mock-pool-instance :- JRubyInstance
     pool-manager-protocol/PoolManagerService
     []
     (create-pool
-     [this jruby-config]
+     [_this jruby-config]
      (create-mock-pool jruby-config (partial mock-jruby-puppet-fn config))))))
 
 (defn add-mock-jruby-pool-manager-service
