@@ -1,14 +1,23 @@
 (ns puppetlabs.services.master.master-core-test
   (:require [cheshire.core :as json]
             [clojure.string :refer [split]]
-            [clojure.test :refer :all]
+            [clojure.test :refer [deftest is testing use-fixtures]]
             [puppetlabs.comidi :as comidi]
             [puppetlabs.kitchensink.core :as ks]
             [puppetlabs.services.jruby-pool-manager.impl.jruby-pool-manager-core
              :as
              jruby-pool-manager-core]
             [puppetlabs.services.jruby-pool-manager.jruby-core :as jruby-core]
-            [puppetlabs.services.master.master-core :refer :all]
+            [puppetlabs.services.master.master-core :refer [root-routes
+                                                            wrap-middleware
+                                                            if-none-match-from-request
+                                                            class-info-from-jruby->class-info-for-json
+                                                            valid-static-file-path?
+                                                            validate-memory-requirements!
+                                                            meminfo-content
+                                                            max-heap-size
+                                                            task-file-uri-components
+                                                            all-tasks-response!]]
             [puppetlabs.services.master.master-service :as master-service]
             [puppetlabs.services.protocols.jruby-puppet :as jruby]
             [puppetlabs.trapperkeeper.testutils.logging :as logging]
@@ -42,7 +51,8 @@
                    true
                    nil
                    ["./dev-resources/puppetlabs/services/master/master_core_test/builtin_bolt_content"]
-                   "./dev-resources/puppetlabs/services/master/master_core_test/bolt_projects")
+                   "./dev-resources/puppetlabs/services/master/master_core_test/bolt_projects"
+                   "test-certname")
       (comidi/routes->handler)
       (wrap-middleware identity puppet-version)))
 
@@ -56,10 +66,12 @@
         request     (partial app-request app)]
     (is (= 200 (:status (request "/v3/environments"))))
     (is (= 200 (:status (request "/v3/catalog/bar?environment=environment1234"))))
-    (is (= 200 (:status (app (-> {:request-method :post
-                                  :uri "/v3/catalog/bar"
-                                  :content-type "application/x-www-form-urlencoded"}
-                                 (ring-mock/body "environment=environment1234"))))))
+    (let [response (app (-> {:request-method :post
+                             :uri "/v3/catalog/bar"
+                             :content-type "application/x-www-form-urlencoded"}
+                            (ring-mock/body "environment=environment1234")))]
+      (is (= "test-certname" (get-in response [:headers "X-Puppet-Compiler-Name"]))
+      (is (= 200 (:status response)))))
     (is (nil? (request "/foo")))
     (is (nil? (request "/foo/bar")))
     (doseq [[method paths]
@@ -106,7 +118,7 @@
                                                                                   :gem-path "bar:foobar"
                                                                                   :ruby-load-path ["foo"]})))
                             (get-environment-class-info [_ _ env]
-                              (if (= env "production")
+                              (when (= env "production")
                                 {}))
                             (get-cached-content-version
                               [_ _ _])
@@ -273,8 +285,7 @@
       (is (every? (complement get-validity) invalid-path-results) (ks/pprint-to-string invalid-path-results)))))
 
 (deftest file-bucket-file-content-type-test
-  (testing (str "The 'Content-Type' header on incoming /file_bucket_file requests "
-                "is not overwritten, and simply passed through unmodified.")
+  (testing "The 'Content-Type' header on incoming /file_bucket_file requests is not overwritten, and simply passed through unmodified."
     (let [handler     (fn ([req] {:request req}))
           app         (build-ring-handler handler "1.2.3" dummy-jruby-service)
           resp        (app (-> {:request-method :put
@@ -284,11 +295,10 @@
       (is (= "application/octet-stream"
              (get-in resp [:request :content-type])))
 
-      (testing "Even if the client sends something insane, "
-               "just pass it through and let the puppet code handle it."
+      (testing "Even if the client sends something insane, just pass it through and let the puppet code handle it."
         (let [resp (app (-> {:request-method :put
-                          :content-type "something-crazy/for-content-type"
-                          :uri "/v3/file_bucket_file/bar"}
+                             :content-type "something-crazy/for-content-type"
+                             :uri "/v3/file_bucket_file/bar"}
                             (ring-mock/body "foo")))]
           (is (= "something-crazy/for-content-type"
                  (get-in resp [:request :content-type]))))))))
@@ -367,7 +377,7 @@
                                                                                   :gem-path "bar:foobar"
                                                                                   :ruby-load-path ["foo"]})))
                             (get-tasks [_ _ env]
-                              (if (= env "production")
+                              (when (= env "production")
                                 [])))
             handler (fn ([req] {:request req}))
             app (build-ring-handler handler "1.2.3" jruby-service)
@@ -375,8 +385,7 @@
             response (fn [info]
                       (all-tasks-response!
                         info
-                       "production"
-                       jruby-service))
+                        "production"))
             response-format (fn [task-name]
                                  {:name task-name
                                   :environment [{:name "production"
