@@ -1,7 +1,7 @@
 (ns puppetlabs.services.request-handler.request-handler-core-test
   (:import (java.io StringReader ByteArrayInputStream)
            (com.puppetlabs.puppetserver JRubyPuppetResponse))
-  (:require [clojure.test :refer :all]
+  (:require [clojure.test :refer [deftest is testing]]
             [slingshot.test :refer :all]
             [ring.util.codec :as ring-codec]
             [puppetlabs.ring-middleware.utils :as ringutils]
@@ -11,12 +11,12 @@
             [puppetlabs.trapperkeeper.testutils.logging :as logutils]
             [puppetlabs.services.jruby.jruby-puppet-testutils :as jruby-testutils]
             [puppetlabs.trapperkeeper.app :as tk-app]
-            [puppetlabs.trapperkeeper.services :refer [defservice service]]
+            [puppetlabs.trapperkeeper.services :refer [service]]
             [puppetlabs.services.jruby.jruby-puppet-service :as jruby-service]
             [puppetlabs.puppetserver.bootstrap-testutils :as jruby-bootstrap]
             [puppetlabs.services.protocols.versioned-code :as vc]
             [puppetlabs.services.puppet-profiler.puppet-profiler-service :as profiler]
-            [puppetlabs.trapperkeeper.services.webserver.jetty9-service :as jetty9]
+            [puppetlabs.trapperkeeper.services.webserver.jetty10-service :as jetty10]
             [puppetlabs.trapperkeeper.services.scheduler.scheduler-service :as tk-scheduler]
             [puppetlabs.services.request-handler.request-handler-service :as handler-service]
             [puppetlabs.services.config.puppet-server-config-service :as ps-config]
@@ -67,7 +67,7 @@
                              :content-type "text/plain"})]
       (is (= {} (:params wrapped-request))
           "Unexpected params in wrapped request")
-      (is (= "" (:body wrapped-request))
+      (is (= "" (slurp (:body wrapped-request)))
           "Unexpected body for jruby in wrapped request")))
   (testing "get with query parameters returns expected values"
     (let [wrapped-request (core/wrap-params-for-jruby
@@ -79,14 +79,14 @@
               :bogus ""}
              (:params wrapped-request))
           "Unexpected params in wrapped request")
-      (is (= "" (:body wrapped-request))
+      (is (= "" (slurp (:body wrapped-request)))
           "Unexpected body for jruby in wrapped request")))
   (testing "post with form parameters returns expected values"
     (let [body-string "one=1&two=2%202&arr[]=3&arr[]=4"
           wrapped-request (core/wrap-params-for-jruby
-                            {:body         (StringReader. body-string)
-                             :content-type "application/x-www-form-urlencoded"
-                             :params       {:bogus ""}})]
+                           {:body (StringReader. body-string)
+                            :content-type "application/x-www-form-urlencoded"
+                            :params {:bogus ""}})]
       (is (= {"one" "1", "two" "2 2", "arr[]" ["3" "4"]
               :bogus ""}
              (:params wrapped-request))
@@ -101,7 +101,7 @@
                              :params       {:bogus ""}})]
       (is (= {:bogus ""} (:params wrapped-request))
           "Unexpected params in wrapped request")
-      (is (= body-string (:body wrapped-request))
+      (is (= body-string (slurp (:body wrapped-request)))
           "Unexpected body for jruby in wrapped request")))
   (testing "post with plain text in UTF-16 returns expected values"
     (let [body-string-from-utf16 (String. (.getBytes
@@ -117,7 +117,7 @@
                              :params             {:bogus ""}})]
       (is (= {:bogus ""} (:params wrapped-request))
           "Unexpected params in wrapped request")
-      (is (= body-string-from-utf16 (:body wrapped-request))
+      (is (= body-string-from-utf16 (slurp (:body wrapped-request) :encoding "UTF-16"))
           "Unexpected body for jruby in wrapped request")))
   (testing "request with binary content type does not consume body"
     (let [body-string "some random text"]
@@ -174,120 +174,121 @@
                               (get req :client-cert))))))))))
 
 (deftest cert-info-in-headers
-  "In the case where Puppet Server is running under HTTP with an upstream HTTPS
-  terminator, the cert's CN, cert, and authenticated status will be provided as
-  HTTP headers.  If cert info is not provided in the headers but is available
-  via SSL, the SSL info will be used."
-  (logutils/with-test-logging
-    (let [single-cert-url-encoded (-> (str test-resources-dir "/localhost.pem")
-                                      slurp
-                                      ring-codec/url-encode)
-          second-cert-url-encoded (-> (str test-resources-dir "/master.pem")
-                                      slurp
-                                      ring-codec/url-encode)]
+  (testing
+    "In the case where Puppet Server is running under HTTP with an upstream HTTPS
+    terminator, the cert's CN, cert, and authenticated status will be provided as
+    HTTP headers.  If cert info is not provided in the headers but is available
+    via SSL, the SSL info will be used."
+    (logutils/with-test-logging
+      (let [single-cert-url-encoded (-> (str test-resources-dir "/localhost.pem")
+                                        slurp
+                                        ring-codec/url-encode)
+            second-cert-url-encoded (-> (str test-resources-dir "/master.pem")
+                                        slurp
+                                        ring-codec/url-encode)]
 
-      (testing "providing headers but not the puppet server config won't work."
-        (let [req (core/as-jruby-request
-                   (puppetserver-config false)
-                   {:request-method :get
-                    :headers        {"x-client-verify" "SUCCESS"
-                                     "x-client-dn"     "CN=puppet"
-                                     "x-client-cert"   single-cert-url-encoded}})]
-          (is (not (get req :authenticated)))
-          (is (nil? (get req :client-cert-cn)))
-          (is (nil? (get req :client-cert)))))
+        (testing "providing headers but not the puppet server config won't work."
+          (let [req (core/as-jruby-request
+                     (puppetserver-config false)
+                     {:request-method :get
+                      :headers        {"x-client-verify" "SUCCESS"
+                                       "x-client-dn"     "CN=puppet"
+                                       "x-client-cert"   single-cert-url-encoded}})]
+            (is (not (get req :authenticated)))
+            (is (nil? (get req :client-cert-cn)))
+            (is (nil? (get req :client-cert)))))
 
-      (testing "providing headers and allow-header-cert-info to true works"
-        (let [req (core/as-jruby-request
-                   (puppetserver-config true)
-                   {:request-method :get
-                    :headers        {"x-client-verify" "SUCCESS"
-                                     "x-client-dn"     "CN=puppet"
-                                     "x-client-cert"   single-cert-url-encoded}})]
-          (is (get req :authenticated))
-          (is (= "puppet" (get req :client-cert-cn)))
-          (is (= "CN=localhost"
-                 (ssl-utils/get-subject-from-x509-certificate
-                  (get req :client-cert))))))
+        (testing "providing headers and allow-header-cert-info to true works"
+          (let [req (core/as-jruby-request
+                     (puppetserver-config true)
+                     {:request-method :get
+                      :headers        {"x-client-verify" "SUCCESS"
+                                       "x-client-dn"     "CN=puppet"
+                                       "x-client-cert"   single-cert-url-encoded}})]
+            (is (get req :authenticated))
+            (is (= "puppet" (get req :client-cert-cn)))
+            (is (= "CN=localhost"
+                   (ssl-utils/get-subject-from-x509-certificate
+                    (get req :client-cert))))))
 
-      (testing "a malformed DN string fails"
-        (let [req (core/as-jruby-request
-                   (puppetserver-config true)
-                   {:request-method :get
-                    :headers        {"x-client-verify" "SUCCESS"
-                                     "x-client-dn"     "invalid-dn"}})]
-          (is (not (get req :authenticated)))
-          (is (nil? (get req :client-cert)))
-          (is (nil? (get req :client-cert-cn)))))
+        (testing "a malformed DN string fails"
+          (let [req (core/as-jruby-request
+                     (puppetserver-config true)
+                     {:request-method :get
+                      :headers        {"x-client-verify" "SUCCESS"
+                                       "x-client-dn"     "invalid-dn"}})]
+            (is (not (get req :authenticated)))
+            (is (nil? (get req :client-cert)))
+            (is (nil? (get req :client-cert-cn)))))
 
-      (testing "Setting the auth header to something other than 'SUCCESS' fails"
-        (let [req (core/as-jruby-request
-                   (puppetserver-config true)
-                   {:request-method :get
-                    :headers        {"x-client-verify" "fail"
-                                     "x-client-dn"     "CN=puppet"}})]
-          (is (not (get req :authenticated)))
-          (is (= "puppet" (get req :client-cert-cn)))
-          (is (nil? (get req :client-cert)))))
+        (testing "Setting the auth header to something other than 'SUCCESS' fails"
+          (let [req (core/as-jruby-request
+                     (puppetserver-config true)
+                     {:request-method :get
+                      :headers        {"x-client-verify" "fail"
+                                       "x-client-dn"     "CN=puppet"}})]
+            (is (not (get req :authenticated)))
+            (is (= "puppet" (get req :client-cert-cn)))
+            (is (nil? (get req :client-cert)))))
 
-      (testing "cert and cn from header used and not from SSL cert when allow-header-cert-info true"
-        (let [cert (ssl-utils/pem->cert
-                     (str test-resources-dir "/localhost.pem"))
-              req (core/as-jruby-request
-                   (puppetserver-config true)
-                   {:request-method  :get
-                    :ssl-client-cert cert
-                    :headers         {"x-client-verify" "SUCCESS"
-                                      "x-client-dn"     "CN=puppet"
-                                      "x-client-cert"    second-cert-url-encoded}})]
-          (is (get req :authenticated))
-          (is (= "puppet" (get req :client-cert-cn)))
-          (is (= "CN=master1.example.org"
-                 (ssl-utils/get-subject-from-x509-certificate
-                  (get req :client-cert))))))
+        (testing "cert and cn from header used and not from SSL cert when allow-header-cert-info true"
+          (let [cert (ssl-utils/pem->cert
+                       (str test-resources-dir "/localhost.pem"))
+                req (core/as-jruby-request
+                     (puppetserver-config true)
+                     {:request-method  :get
+                      :ssl-client-cert cert
+                      :headers         {"x-client-verify" "SUCCESS"
+                                        "x-client-dn"     "CN=puppet"
+                                        "x-client-cert"    second-cert-url-encoded}})]
+            (is (get req :authenticated))
+            (is (= "puppet" (get req :client-cert-cn)))
+            (is (= "CN=master1.example.org"
+                   (ssl-utils/get-subject-from-x509-certificate
+                    (get req :client-cert))))))
 
-      (testing "cert and cn from ssl used when allow-header-cert-info false"
-        (let [cert (ssl-utils/pem->cert
-                     (str test-resources-dir "/localhost.pem"))
-              req (core/as-jruby-request
-                   (puppetserver-config false)
-                   {:request-method  :get
-                    :ssl-client-cert cert
-                    :headers         {"x-client-verify" "SUCCESS"
-                                      "x-client-dn"     "CN=puppet"
-                                      "x-client-cert"   second-cert-url-encoded}})]
-          (is (get req :authenticated))
-          (is (= "localhost" (get req :client-cert-cn)))
-          (is (identical? cert (get req :client-cert))))))))
+        (testing "cert and cn from ssl used when allow-header-cert-info false"
+          (let [cert (ssl-utils/pem->cert
+                       (str test-resources-dir "/localhost.pem"))
+                req (core/as-jruby-request
+                     (puppetserver-config false)
+                     {:request-method  :get
+                      :ssl-client-cert cert
+                      :headers         {"x-client-verify" "SUCCESS"
+                                        "x-client-dn"     "CN=puppet"
+                                        "x-client-cert"   second-cert-url-encoded}})]
+            (is (get req :authenticated))
+            (is (= "localhost" (get req :client-cert-cn)))
+            (is (identical? cert (get req :client-cert)))))))))
 
 (deftest cert-decoding-failures
-  "A cert provided in the x-client-cert header that cannot be decoded into
-  an X509Certificate object throws the expected failure"
-  (testing "Improperly URL encoded content"
-    (is (thrown+? #(and
-                     (= (:kind %) :bad-request)
-                     (re-matches
-                       #"Unable to URL decode the x-client-cert header: For input string: \"1Q\".*"
-                       (:msg %)))
-                  (jruby-request-with-client-cert-header "%1Q%2"))))
-  (testing "Bad certificate content"
-    (is (thrown+? [:kind :bad-request
-                   :msg (str "Unable to parse x-client-cert into "
-                             "certificate: -----END CERTIFICATE not found")]
-                  (jruby-request-with-client-cert-header
-                    "-----BEGIN%20CERTIFICATE-----%0AM"))))
-  (testing "No certificate in content"
-    (is (thrown+? [:kind :bad-request
-                   :msg "No certs found in PEM read from x-client-cert"]
-                  (jruby-request-with-client-cert-header
-                    "NOCERTSHERE"))))
-  (testing "More than 1 certificate in content"
-    (is (thrown+? [:kind :bad-request
-                   :msg "Only 1 PEM should be supplied for x-client-cert but 3 found"]
-                  (jruby-request-with-client-cert-header
-                    (-> (str test-resources-dir "/master-with-all-cas.pem")
-                        slurp
-                        ring-codec/url-encode))))))
+  (testing "A cert provided in the x-client-cert header that cannot be decoded into
+            an X509Certificate object throws the expected failure"
+    (testing "Improperly URL encoded content"
+      (is (thrown+? #(and
+                       (= (:kind %) :bad-request)
+                       (re-matches
+                         #"Unable to URL decode the x-client-cert header: For input string: \"1Q\".*"
+                         (:msg %)))
+                    (jruby-request-with-client-cert-header "%1Q%2"))))
+    (testing "Bad certificate content"
+      (is (thrown+? [:kind :bad-request
+                     :msg (str "Unable to parse x-client-cert into "
+                               "certificate: -----END CERTIFICATE not found")]
+                    (jruby-request-with-client-cert-header
+                      "-----BEGIN%20CERTIFICATE-----%0AM"))))
+    (testing "No certificate in content"
+      (is (thrown+? [:kind :bad-request
+                     :msg "No certs found in PEM read from x-client-cert"]
+                    (jruby-request-with-client-cert-header
+                      "NOCERTSHERE"))))
+    (testing "More than 1 certificate in content"
+      (is (thrown+? [:kind :bad-request
+                     :msg "Only 1 PEM should be supplied for x-client-cert but 3 found"]
+                    (jruby-request-with-client-cert-header
+                      (-> (str test-resources-dir "/master-with-all-cas.pem")
+                          slurp
+                          ring-codec/url-encode)))))))
 
 (deftest ^:integration test-jruby-pool-not-full-during-code-id-generation
    (testing "A jruby instance is held while code id is generated"
@@ -324,7 +325,7 @@
                      profiler/puppet-profiler-service
                      handler-service/request-handler-service
                      ps-config/puppet-server-config-service
-                     jetty9/jetty9-service
+                     jetty10/jetty10-service
                      ca-service/certificate-authority-service
                      authorization-service/authorization-service
                      routing-service/webrouting-service
@@ -342,7 +343,7 @@
         app services {:jruby-puppet {:max-active-instances 1}}
         (partial jruby-testutils/create-mock-jruby-puppet
                  (fn [request]
-                   (JRubyPuppetResponse. (Integer. 200)
+                   (JRubyPuppetResponse. (int 200)
                                          (cheshire/generate-string
                                           {"classes" []
                                            "environment" "production"
